<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: MaintenanceStatisticsCommon.mtcdb.test.php 3335 2005-06-10 11:41:30Z andrew $
*/

require_once MAX_PATH . '/lib/Max.php';
require_once MAX_PATH . '/lib/max/DB.php';
require_once MAX_PATH . '/lib/max/Table/Core.php';
require_once MAX_PATH . '/lib/max/Maintenance/Statistics.php';
require_once 'Date.php';

/**
 * A class for testing the Maintenance_Statistics_Common class.
 *
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@m3.net>
 * @TODO Update to use a mocked DAL, instead of a real database.
 */
class Maintenance_TestOfMaintenanceStatisticsCommon extends UnitTestCase
{
    
    /**
     * The constructor method.
     */
    function Maintenance_TestOfMaintenanceStatisticsCommon()
    {        
        $this->UnitTestCase();
    }
    
    /**
     * Tests the constructor method. Uses the AdServer module
     * as a basis, but the test is equally valid for other modules,
     * as the mechanism by which the modules differ is tested in
     * the Dal package.
     */
    function testMaintenance_Statistics_Common()
    {
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $tables = MAX_Table_Core::singleton();
        // Create the required tables
        $tables->createTable('data_raw_ad_impression');
        $tables->createTable('log_maintenance_statistics');
        // Create a Maintenance_Statistics_Common object with no data,
        // and an operation interval less than 60
        $conf['maintenance']['operationInterval'] = 30;
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements();
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Create a Maintenance_Statistics_Common object with no data,
        // and an operation interval greater than 60
        $conf['maintenance']['operationInterval'] = 120;
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements();
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        /*----------------------------------------------------------*/
        /* Run tests relating to a 30 minute operation interval     */
        /*----------------------------------------------------------*/
        $conf['maintenance']['operationInterval'] = 30;
        // Insert ad impression data 5 minutes ago, in current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:05:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 20 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 17:50:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 20 minutes ago, in current hour
        // and current operation interval
        $now = new Date('2004-06-06 18:25:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:05:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 20 minutes ago, in current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:45:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:25:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 39 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 17:31:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 39 minutes ago, in current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:01:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 61 minutes ago, in previous hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 17:39:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        /*----------------------------------------------------------*/
        /* Run tests relating to a 120 minute operation interval    */
        /*----------------------------------------------------------*/
        $conf['maintenance']['operationInterval'] = 120;
        // Insert ad impression data 5 minutes ago, in current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:05:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 20 minutes ago, in previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:50:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 20 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 17:50:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 20 minutes ago, in current hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:20:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 61 minutes ago, in previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 18:39:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 61 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 17:39:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        // Insert ad impression data 121 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}
                (date_time)
            VALUES
                ('2004-06-06 16:39:00')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the ad impression
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $result = $dbh->query($query);
        /*----------------------------------------------------------*/
        /* Run tests relating to a 30 minute operation interval     */
        /*----------------------------------------------------------*/
        $conf['maintenance']['operationInterval'] = 30;
        // Insert OI stats run 5 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 0, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert hourly stats run 5 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 0, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 20 minutes ago, up to  previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:50:00', 0, '2004-06-06 17:29:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert hourly stats run 20 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:50:00', 1, '2004-06-06 16:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 20 minutes ago, up to current hour
        // and current operation interval
        $now = new Date('2004-06-06 18:25:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 0, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert hourly stats run 20 minutes ago, up to current hour
        // and current operation interval
        $now = new Date('2004-06-06 18:25:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 1, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 20 minutes ago, up to current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:45:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:25:00', 0, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 20 minutes ago, up to current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:45:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:25:00', 1, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run data 39 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:31:00', 0, '2004-06-06 17:29:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run data 39 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:31:00', 1, '2004-06-06 16:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 39 minutes ago, up to current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:01:00', 0, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert hourly stats run 39 minutes ago, up to current hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:01:00', 1, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 61 minutes ago, up to previous hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:39:00', 0, '2004-06-06 17:29:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 61 minutes ago, in previous hour
        // and previous operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:39:00', 1, '2004-06-06 16:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertTrue($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        /*----------------------------------------------------------*/
        /* Run tests relating to a 120 minute operation interval    */
        /*----------------------------------------------------------*/
        $conf['maintenance']['operationInterval'] = 120;
        // Insert OI stats run 5 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 0, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert hourly stats run 5 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:05:00', 1, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 20 minutes ago, up to previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:50:00', 0, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 20 minutes ago, up to previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:50:00', 1, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 20 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:50:00', 0, '2004-06-06 15:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert hourly stats run 20 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:10:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:50:00', 1, '2004-06-06 16:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 20 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:20:00', 0, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert hourly stats run 20 minutes ago, up to current hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:20:00', 1, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 61 minutes ago, up to previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:39:00', 0, '17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert hourly stats run 61 minutes ago, up to previous hour
        // and current operation interval
        $now = new Date('2004-06-06 19:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 18:39:00', 1, '2004-06-06 17:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 61 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:39:00', 0, '2004-06-06 15:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert hourly stats run 61 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 17:39:00', 1, '2004-06-06 16:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert OI stats run 121 minutes ago, up to previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 16:39:00', 0, '2004-06-06 15:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertTrue($msObj->updateOI);
        $this->assertFalse($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Insert hourly stats run 121 minutes ago, in previous hour
        // and operation interval
        $now = new Date('2004-06-06 18:40:00');
        $query = "INSERT INTO
            {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
                (start_run, adserver_run_type, updated_to)
            VALUES
                ('2004-06-06 16:39:00', 1, '2004-06-06 15:59:59')";
        $result = $dbh->query($query);
        // Test
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        $this->assertEqual($msObj->module, 'AdServer');
        $this->assertFalse($msObj->updateUsingOI);
        $this->assertFalse($msObj->updateOI);
        $this->assertTrue($msObj->updateHourly);
        // Delete the run log information
        $query = "DELETE FROM {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}";
        $result = $dbh->query($query);
        // Reset the testing environment
        TestEnv::restoreEnv();
    }
    
    /**
     * Tests the deleteOldData() method. Uses the AdServer module
     * as a basis, but the test is equally valid for other modules,
     * as the mechanism by which the modules differ is tested in
     * the Dal package.
     */
    function testDeleteOldData()
    {
        $conf = &$GLOBALS['_MAX']['CONF'];
        $conf['maintenance']['operationInterval'] = 60;
        $conf['table']['prefix'] = 'max_';
        $conf['table']['split'] = false;
        $tables = MAX_Table_Core::singleton();
        $dbh =& MAX_DB::singleton();
        // Create the required tables
        $tables->createTable('campaigns_trackers');
        $tables->createTable('data_raw_ad_click');
        $tables->createTable('data_raw_ad_impression');
        $tables->createTable('data_raw_ad_request');
        $tables->createTable('log_maintenance_statistics');
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Maintenance/data/TestOfMaintenanceStatisticsCommon.php';
        // Insert the test data
        $result = $dbh->query(COMMON_DELETE_OLD_DATA_CAMPAIGNS_TRACKERS);
        $result = $dbh->query(COMMON_DELETE_OLD_DATA_AD_CLICKS);
        $result = $dbh->query(COMMON_DELETE_OLD_DATA_AD_IMPRESSIONS);
        $result = $dbh->query(COMMON_DELETE_OLD_DATA_AD_REQUESTS);
        // Set compact_stats to false
        $conf['maintenance']['compactStats'] = false;
        // Create a new Maintenance_Statistics_Common object
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements();
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_request']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        // Set compact_stats to true
        $conf['maintenance']['compactStats'] = true;
        // Set compact_stats grace to one hour
        $conf['maintenance']['compactStatsGrace'] = 3600;
        // Disable the tracker
        $conf['modules']['Tracker'] = false;
        // Create a new Maintenance_Statistics_Common object
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements();
        // Set the Maintenance_Statistics_Common object to not have updated
        $msObj->updateHourly = false;
        $msObj->updateOI = false;
        $msObj->updateUsingOI = false;
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_request']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        // Set the Maintenance_Statistics_Common object to have updated by the hour,
        // but not to have updated using the OI
        $msObj->updateHourly = true;
        $msObj->updateOI = false;
        $msObj->updateUsingOI = false;
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_request']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        // Set the Maintenance_Statistics_Common object to have updated by the
        // operation interval, but to have updated using the OI
        $msObj->updateHourly = false;
        $msObj->updateOI = true;
        $msObj->updateUsingOI = true;
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_request']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        // Set the Maintenance_Statistics_Common object to have updated by the hour,
        // and to have updated using the OI, with an upToDateHourly date
        $msObj->updateHourly = true;
        $msObj->updateOI = false;
        $msObj->updateUsingOI = true;
        $msObj->upToDateHourly = new Date('2004-06-06 17:59:59');
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_request']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        // Drop and re-create the tables
        $tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_click']);
        $tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_impression']);
        $tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_request']);
        $tables->dropTable($conf['table']['prefix'].$conf['table']['log_maintenance_statistics']);
        $tables->createTable('data_raw_ad_click');
        $tables->createTable('data_raw_ad_impression');
        $tables->createTable('data_raw_ad_request');
        $tables->createTable('log_maintenance_statistics');
        // Re-insert the test data
        $result = $dbh->query(COMMON_DELETE_OLD_DATA_AD_CLICKS);
        $result = $dbh->query(COMMON_DELETE_OLD_DATA_AD_IMPRESSIONS);
        $result = $dbh->query(COMMON_DELETE_OLD_DATA_AD_REQUESTS);
        // Set the Maintenance_Statistics_Common object to have updated by the
        // operation interval, and to have NOT updated using the OI, with an upToDateOI date
        $msObj->updateHourly = false;
        $msObj->updateOI = true;
        $msObj->updateUsingOI = false;
        $msObj->upToDateOI = new Date('2004-06-06 17:59:59');
        // Test
        $msObj->deleteOldData();
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_request']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        // Reset the testing environment
        TestEnv::restoreEnv();
    }
    
    /**
     * Tests the logCompletion() method. Uses the AdServer module
     * as a basis, but the test is equally valid for other modules,
     * as the mechanism by which the modules differ is tested in
     * the Dal package.
     */
    function testLogCompletion()
    {
        $conf =& $GLOBALS['_MAX']['CONF'];
        $tables = MAX_Table_Core::singleton();
        $dbh =& MAX_DB::singleton();
        // Create the required table
        $tables->createTable('data_raw_ad_impression');
        $tables->createTable('log_maintenance_statistics');
        $tables->createTable('userlog');
        // Create a Maintenance_Statistics_AdServer object
        $now = new Date('2004-06-06 18:10:00');
        $ms = &new Maintenance_Statistics();
        $msObj = $ms->instance('AdServer');
        $msObj->setUpdateRequirements($now);
        // Set some of the object's variables, and log
        $msObj->updateOI = true;
        $msObj->upToDateOI = new Date('2004-06-06 17:59:59');
        $msObj->updateHourly = false;
        $msObj->upToDateHourly = null;
        $end = new Date('2004-06-06 18:12:00');
        $msObj->logCompletion($end);
        // Test
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 0";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['start_run'], '2004-06-06 18:10:00');
        $this->assertEqual($row['end_run'], '2004-06-06 18:12:00');
        $this->assertEqual($row['duration'], 120);
        $this->assertEqual($row['updated_to'], '2004-06-06 17:59:59');
        // Set some of the object's variables, and log
        $msObj->updateOI = false;
        $msObj->upToDateOI = null;
        $msObj->updateHourly = true;
        $msObj->upToDateHourly = new Date('2004-06-06 17:59:59');
        $end = new Date('2004-06-06 18:13:00');
        $msObj->logCompletion($end);
        // Test
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 1";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['start_run'], '2004-06-06 18:10:00');
        $this->assertEqual($row['end_run'], '2004-06-06 18:13:00');
        $this->assertEqual($row['duration'], 180);
        $this->assertEqual($row['updated_to'], '2004-06-06 17:59:59');
        // Set some of the object's variables, and log
        $msObj->updateOI = true;
        $msObj->upToDateOI = new Date('2004-06-06 17:59:59');
        $msObj->updateHourly = true;
        $msObj->upToDateHourly = new Date('2004-06-06 17:59:59');
        $end = new Date('2004-06-06 18:14:00');
        $msObj->logCompletion($end);
        // Test
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 2";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['start_run'], '2004-06-06 18:10:00');
        $this->assertEqual($row['end_run'], '2004-06-06 18:14:00');
        $this->assertEqual($row['duration'], 240);
        $this->assertEqual($row['updated_to'], '2004-06-06 17:59:59');
        // Reset the testing environment
        TestEnv::restoreEnv();
    }
    
}

?>
