<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 m3 Media Services Limited                         |
| For contact details, see: http://www.m3.net/                              |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: PriorityAdServerAllocateZoneImpressions.mtp.test.php 3416 2005-06-30 14:40:49Z andrew $
*/

require_once 'Date.php';
require_once MAX_PATH . '/lib/max/Maintenance/Priority/AdServer/tasks/AllocateZoneImpressions.php';

/**
 * A class for testing the Maintenance_Priority_AdServer_AdvertisementZoneImpressionAllocation class.
 *
 * @package    MaxMaintenance
 * @subpackage TestSuite
 * @author     Demian Turner <demian@m3.net>
 */
class TestOfPriorityAdserverAllocateZoneImpressions extends UnitTestCase
{
    
    /**
     * The constructor method.
     */
    function TestOfPriorityAdserverAllocateZoneImpressions()
    {        
        $this->UnitTestCase();
        Mock::generate('MAX_Dal_Maintenance');
        Mock::generate('MAX_Table_Priority');
    }
    
    function testRun()
    {
        $obj = $this->getCurrentTask();
        $obj->run();
    }
    
    function getCurrentTask()
    {
        // Mock the MAX_Dal_Maintenance class used in the constructor method
        $oDal = &new MockMAX_Dal_Maintenance($this);
        $oServiceLocator = &ServiceLocator::instance();
        $oServiceLocator->register('MAX_Dal_Maintenance', $oDal);
        // Mock the MAX_Table_Priority class used in the constructor method
        $oTable = &new MockMAX_Table_Priority($this);
        $oServiceLocator = &ServiceLocator::instance();
        $oServiceLocator->register('MAX_Table_Priority', $oTable);
        return new AllocateZoneImpressions();
    }
    
    function testSetRequiredImpressions()
    {
        Mock::generatePartial(
            'AllocateZoneImpressions', 
            'PartialMockAllocateZoneImpressions', 
            array('getAdRequiredImpressions')
        );
        $adAllocZoneImpressions = &new PartialMockAllocateZoneImpressions($this);
        $adAllocZoneImpressions->setReturnReference('getAdRequiredImpressions', rand(1, 999));
        $adAllocZoneImpressions->AllocateZoneImpressions();
        // Generate random Adverts where no required impressions in database
        $aAds = array();
        for ($x = 0; $x <= 10; $x++) {
            $obj = new Advert();
            $obj->id = rand(0, 999);
            $aAds[] = $obj;
        }
        // Test the results
        $adAllocZoneImpressions->setRequiredImpressions($aAds);
        foreach ($aAds as $oAd) {
            $this->assertTrue(isset($oAd->requiredImpressions));
            $this->assertEqual($oAd->requiredImpressions, 0);
        }
        // Generate set Adverts with required impressions in database
        $aAds = array();
        $oAdvert = new Advert();
        $oAdvert->id = 1;
        $aAds[] = $oAdvert;
        $oAdvert = new Advert();
        $oAdvert->id = 2;
        $aAds[] = $oAdvert;
        $oAdvert = new Advert();
        $oAdvert->id = 3;
        $aAds[] = $oAdvert;
        $adAllocZoneImpressions->oDal->setReturnValue(
            'getRequiredAdImpressions',
            array(
                1 => 5,
                2 => 15,
                3 => 25
            )
        );
        // Test the results
        $adAllocZoneImpressions->setRequiredImpressions($aAds);
        $this->assertEqual($aAds[0]->id, 1);
        $this->assertEqual($aAds[0]->requiredImpressions, 5);
        $this->assertEqual($aAds[1]->id, 2);
        $this->assertEqual($aAds[1]->requiredImpressions, 15);
        $this->assertEqual($aAds[2]->id, 3);
        $this->assertEqual($aAds[2]->requiredImpressions, 25);
    }
    
    function testOrderAdsByRequiredImpressions()
    {
        $collection = array();
        for ($x = 0; $x <= 10; $x++) {
            $obj = new Advert();
            $obj->requiredImpressions = rand(0, 999);
            $collection[] = $obj;
        }
        
        foreach ($collection as $k => $oAdvert) {
            $impressions[$k] = $oAdvert->requiredImpressions;  
        }
        
        array_multisort($impressions, SORT_DESC, $collection);
        
        //  assert ordering from greatest to least
        foreach ($collection as $k => $advert) {
            $this->assertTrue($collection[$k]->requiredImpressions > @$collection[$k+1]->requiredImpressions);
        }
    }
    
}

?>
